<?php

namespace Boomee\Education\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Boomee\Education\Http\Requests\EducationRequest;
use Boomee\Education\Interfaces\EducationRepositoryInterface;
use Boomee\Education\Models\Education;
use Boomee\Education\Forms\Education as Form;

/**
 * APIController  class for education.
 */
class EducationAPIController extends BaseController
{

    /**
     * Initialize education resource controller.
     *
     * @param type EducationRepositoryInterface $education
     *
     * @return null
     */
    public function __construct(EducationRepositoryInterface $education)
    {
        parent::__construct();
        $this->repository = $education;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Boomee\Education\Repositories\Criteria\EducationResourceCriteria::class);
    }

    /**
     * Display a list of education.
     *
     * @return Response
     */
    public function index(EducationRequest $request)
    {
        return $this->repository
            ->setPresenter(\Boomee\Education\Repositories\Presenter\EducationPresenter::class)
            ->paginate();
    }

    /**
     * Display education.
     *
     * @param Request $request
     * @param Model   $education
     *
     * @return Response
     */
    public function show(EducationRequest $request, Education $education)
    {
        return $education->setPresenter(\Boomee\Education\Repositories\Presenter\EducationListPresenter::class);
        ;
    }

    /**
     * Create new education.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EducationRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('education::education.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('education/education/' . $education->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('education/education');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the education.
     *
     * @param Request $request
     * @param Model   $education
     *
     * @return Response
     */
    public function update(EducationRequest $request, Education $education)
    {
        try {
            $data = $request->all();

            $education->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('education::education.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('education/education/' . $education->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('education/education/' . $education->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the education.
     *
     * @param Model   $education
     *
     * @return Response
     */
    public function destroy(EducationRequest $request, Education $education)
    {
        try {
            $education->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('education::education.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('education/education/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('education/education/' . $education->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
