<?php

namespace Boomee\Education\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Boomee\Education\Http\Requests\EducationRequest;
use Boomee\Education\Interfaces\EducationRepositoryInterface;
use Boomee\Education\Models\Education;

/**
 * Resource controller class for education.
 */
class EducationResourceController extends BaseController
{

    /**
     * Initialize education resource controller.
     *
     * @param type EducationRepositoryInterface $education
     *
     * @return null
     */
    public function __construct(EducationRepositoryInterface $education)
    {
        parent::__construct();
        $this->repository = $education;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Boomee\Education\Repositories\Criteria\EducationResourceCriteria::class);
    }

    /**
     * Display a list of education.
     *
     * @return Response
     */
    public function index(EducationRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Boomee\Education\Repositories\Presenter\EducationPresenter::class)
                ->$function();
        }

        $education = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('education::education.names'))
            ->view('education::education.index', true)
            ->data(compact('education', 'view'))
            ->output();
    }

    /**
     * Display education.
     *
     * @param Request $request
     * @param Model   $education
     *
     * @return Response
     */
    public function show(EducationRequest $request, Education $education)
    {

        if ($education->exists) {
            $view = 'education::education.show';
        } else {
            $view = 'education::education.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('education::education.name'))
            ->data(compact('education'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new education.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(EducationRequest $request)
    {

        $education = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('education::education.name')) 
            ->view('education::education.create', true) 
            ->data(compact('education'))
            ->output();
    }

    /**
     * Create new education.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EducationRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $education                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('education::education.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('education/education/' . $education->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/education/education'))
                ->redirect();
        }

    }

    /**
     * Show education for editing.
     *
     * @param Request $request
     * @param Model   $education
     *
     * @return Response
     */
    public function edit(EducationRequest $request, Education $education)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('education::education.name'))
            ->view('education::education.edit', true)
            ->data(compact('education'))
            ->output();
    }

    /**
     * Update the education.
     *
     * @param Request $request
     * @param Model   $education
     *
     * @return Response
     */
    public function update(EducationRequest $request, Education $education)
    {
        try {
            $attributes = $request->all();

            $education->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('education::education.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('education/education/' . $education->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('education/education/' . $education->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the education.
     *
     * @param Model   $education
     *
     * @return Response
     */
    public function destroy(EducationRequest $request, Education $education)
    {
        try {

            $education->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('education::education.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('education/education/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('education/education/' . $education->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple education.
     *
     * @param Model   $education
     *
     * @return Response
     */
    public function delete(EducationRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('education::education.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('education/education'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/education/education'))
                ->redirect();
        }

    }

    /**
     * Restore deleted education.
     *
     * @param Model   $education
     *
     * @return Response
     */
    public function restore(EducationRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('education::education.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/education/education'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/education/education/'))
                ->redirect();
        }

    }

}
